@@ -6,17 +6,11 @@ Created on Fri Jun 24 15:10:31 2022
 @author: eadali
 """
 
-from numpy import zeros, random
-from advanced_pid.integrate import RK4
+import random
 
 
 class MassSpringDamper:
-    r"""
-    A mass-spring-damper model.
-
-    Solve a differential equation :math:`m\ddot{x} = -kx - b\dot{x} - u`
-
-    *Note*: https://en.wikipedia.org/wiki/Mass-spring-damper_model
+    """A mass-spring-damper model.
 
     Parameters
     ----------
@@ -39,7 +33,7 @@ class MassSpringDamper:
         self.damping_const = damping_const
         self.noise_std = noise_std
         # Set initial values
-        self.states = zeros(2)
+        self.states = [0.0, 0.0]
         # Set input
         self.external_force = 0.0
 
@@ -83,19 +77,17 @@ class MassSpringDamper:
 
         Returns
         -------
-        measurement_time : float
-            Measurement timestamp.
-        measured_position : float
-            Measured position of mass.
+        tuple:
+            Timestamp and measured position (timestamp, measured_position).
+
         """
         # Update measurement time
         self.measurement_time = self.measurement_time + self.time_step
         # Solve ordinary differential equation for current states
-        _, self.states = RK4(self._state_equation,
-                             (0.0, self.time_step),
-                             self.states,
-                             10)
+        dxdt = self._state_equation(0, self.states)
+        self.states[0] = self.states[0] + dxdt[0] * self.time_step
+        self.states[1] = self.states[1] + dxdt[1] * self.time_step
         position = self.states[0]
-        noise = random.normal(scale=self.noise_std)
+        noise = random.gauss(0, self.noise_std)
         measured_position = position + noise
         return self.measurement_time, measured_position
