@@ -45,6 +45,7 @@ class PID:
         -------
         float
             Control signal.
+
         """
         return self.integrate(t, e)
 
@@ -115,6 +116,7 @@ class PID:
             Initial error. None will reset error.
         i0 : float or None
             Inital integral. None will reset integral.
+
         """
         self.t0, self.e0, self.i0 = t0, e0, i0
 
@@ -125,6 +127,7 @@ class PID:
         -------
         tuple
             Initial states of PID controller (t0, e0, i0)
+
         """
         return self.t0, self.e0, self.i0
 
@@ -159,8 +162,9 @@ class PID:
 
         Returns
         -------
-        u : float
+        float
             Control signal.
+
         """
         self.__set_none_value(t, e)
         t0, e0, i0 = self.get_initial_value()
@@ -181,7 +185,7 @@ class PID:
             x = -Kn * self.Kd * e0
             x = exp(-Kn*dt) * x - Kn * (1.0 - exp(-Kn*dt)) * self.Kd * e
             d = x + Kn * self.Kd * e
-            e = -(1.0/(Kn*self.Kd)) * x
+            e = -(self.Tf/self.Kd) * x
         # Set initial value for next cycle
         self.set_initial_value(t, e, i)
         return min(max(p+i+d, self.lower), self.upper)
